function [PeptideMass, PeptideIntensity, SelInfoContent, AnalyzedPeptideRefer] = AnalyzeDatabaseResult(FileDir, FileBaseName, ScoreThreshold)
% Input
% FileDir:                   The directory for the database searching result
% FileBaseName:              The base filename for the analyzed file
% ScoreThreshold:            The threshold to select the peptides that to be analyzed
% Output
% PeptideMass:               The theoretic isotopic mass values for each peptide
% PeptideIntensity:          The theoretic isotopic intensities for each peptide
% SelInfoContent:            The charge state, scan of ms/ms spectrum to identify the peptide, etc
% AnalyzedPeptideRefer:      The reference codes for the selected peptides

if FileDir(end) == '/'
    file_dir = FileDir;
else
    file_dir = [FileDir, '/'];
end

% load the info file
info_file = [file_dir, FileBaseName, '_info.txt'];
info_content = load(info_file);

% load reference file
refer_file = [file_dir, FileBaseName, '_refer.txt'];
refer_content = load(refer_file);
% sequence file
seq_file = [file_dir, FileBaseName, '_seq.txt'];

% in the initial step, all analyze rows are one; in the following step, the
% rows that are not analyzed are set to zero
analyze_rows = ones(size(info_content, 1), 1);

% scores
thresh_xcorr = ScoreThreshold(1);
thresh_deltacn = ScoreThreshold(2);

tmp_buffer = (info_content(:,3)<=thresh_xcorr | info_content(:,4)<=thresh_deltacn);
analyze_rows(tmp_buffer) = 0;

tmp_analyze_count = length(find(analyze_rows == 1));
peptide_mass = zeros(5, tmp_analyze_count);
peptide_intensity = zeros(5, tmp_analyze_count);
modification_count = (size(info_content, 2) - 7)/2;
% begin to read and create peptide basis
loop_index = 1;
peptide_index = 1;
file_reader = fopen(seq_file, 'r');
while 1
    read_line = fgetl(file_reader);
    if ~ischar(read_line)
        break;
    end
    if analyze_rows(loop_index) == 0
        loop_index = loop_index + 1;
        continue;
    end
    ana_string = read_line;
    if isempty(find(ana_string == 'B', 1)) == 0 || isempty(find(ana_string == 'X', 1)) == 0
        % if find any incorrect peptide, continue
        loop_index = loop_index + 1;
        peptide_index = peptide_index + 1;
        continue;
    end
    peptide_che = GeneratePeptide(ana_string);
    charge_state = info_content(loop_index, 2);
    [mass, intensity] = EstimateIsotope(peptide_che,charge_state, 0);
    %consider modification case
    add_modi = 0;
    for modi_index = 1:modification_count
        sel_modi = 7 + (modi_index - 1 ) * 2 + 1;
        add_modi = add_modi + info_content(loop_index, sel_modi) * info_content(loop_index, sel_modi + 1);
    end
    peptide_mass(:,peptide_index) = mass(1:5) + add_modi / charge_state;
    peptide_intensity(:,peptide_index) = intensity(1:5);
    loop_index = loop_index + 1;
    peptide_index = peptide_index + 1;
end
fclose(file_reader);

% remove zero rows from peptide mass
tmp_buffer = find(analyze_rows == 1);
remove_list = [];

zeros_index = find(sum(peptide_intensity) == 0);
remove_list = [remove_list;zeros_index'];

% remove repeat items from peptide mass
sel_refer = refer_content(analyze_rows == 1);
sel_charge_info = info_content(analyze_rows == 1, 2);
repeat_index = ObtainRepeatList(sel_refer, sel_charge_info);
remove_list = [remove_list; repeat_index];

remove_list = unique(remove_list);
% return the last result
PeptideMass = peptide_mass(1:3,:);
PeptideIntensity = peptide_intensity(1:3,:);
PeptideMass(:, remove_list) = [];
PeptideIntensity(:, remove_list) = [];
analyze_rows(tmp_buffer(remove_list)) = 0;
AnalyzedPeptideRefer = refer_content(analyze_rows==1,:);
SelInfoContent = info_content(analyze_rows == 1,:);

return;

function RepeatIndex = ObtainRepeatList(SelRefer, SelChargeInfo)
new_data_content = zeros(length(SelRefer), 1);

for i=1:length(SelRefer)
    new_str = [num2str(SelRefer(i)), '.', num2str(SelChargeInfo(i))];
    new_data_content(i) = str2double(new_str);
end

[no_use_buffer, unique_index]=unique(new_data_content,'first');

tmp_buffer = ones(length(SelRefer), 1);
tmp_buffer(unique_index) = 0;
RepeatIndex = find(tmp_buffer == 1);